from setuptools import setup

setup(name='rpbtool',
      version='0.0.1',
      description='Tools that commonly used throught my career',
      author='rpb',
      packages=['rpbtool'],
      long_description='Tools that commonly used throught my career',
      install_requires=['mne','numpy','pandas','pickle'],
      )
